@@ -33,7 +33,6 @@ class VisionClassifierTrainer:
   """
   def __init__(
     self,
-    ids2labels,
     output_dir        :str,
     model_name        :str,
     model             :torch.nn.Module,
@@ -66,9 +65,13 @@ class VisionClassifierTrainer:
     self.cores             = cores
     self.fp16              = fp16
     self.eval_metric       = eval_metric
-    self.ids2labels        = ids2labels
     self.balanced          = balanced
     self.augmentation      = augmentation
+    self.ids2labels        = self.model.config.id2label
+    self.labels2ids        = self.model.config.label2id
+    
+    print(self.ids2labels)
+    print(self.labels2ids)
 
     # Processing device (CPU / GPU)
     self.device = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
@@ -161,7 +164,7 @@ class VisionClassifierTrainer:
     all_target, all_preds = self.__evaluate()
 
     # Get the labels as a list
-    labels = list(self.ids2labels.keys())
+    labels = list(self.ids2labels.values())
 
     # Compute f-score
     precision, recall, fscore, support = f_score(all_target, all_preds)
@@ -172,7 +175,7 @@ class VisionClassifierTrainer:
     for i in range(len(labels)):
         table_f_score.append(
           [
-              self.ids2labels[labels[i]],
+              labels[i],
               str(round(precision[i] * 100,2)) + " %",
               str(round(recall[i] * 100,2)) + " %",
               str(round(fscore[i] * 100,2)) + " %",
